<?php
/**
 * Event seats front end class
 *
 * @author 		AJDE
 * @category 	Admin
 * @package 	EventON-st/classes
 * @version     0.1
 */
class evost_front{
	
	function __construct(){
		global $evost;

		$this->evopt1 = get_option('evcal_options_evcal_1');
		$this->evopt2 = get_option('evcal_options_evcal_2');
		$this->opt_tx = get_option('evcal_options_evcal_tx');

		// scripts and styles 
		add_action( 'init', array( $this, 'register_styles_scripts' ) ,15);	

		//event seating
		add_filter('evotx_add_cart_section',array($this,'evotx_seating'),10, 3);

		add_filter('woocommerce_get_cart_item_from_session', array($this,'get_cart_item_meta_values'), 1, 3 );

		// display seat id
		add_filter('woocommerce_cart_item_name',array($this,'add_to_cart_item_names'),1,3);
		add_filter('woocommerce_cart_item_quantity',array($this,'cart_item_quantity'),1,3);

		// display order details
		add_filter('woocommerce_order_items_meta_display', array($this, 'ordermeta_display'), 10,2);
		
		// Checkout ticket with event seats
		add_action('woocommerce_checkout_order_processed', array($this, 'adjust_seat_stock_for_order'), 10, 1);
		add_action('woocommerce_reduce_order_stock', array($this, 'reduce_seat_stock'), 10, 1);
		add_action('woocommerce_restore_order_stock', array($this, 'restock_seat_stock'), 10, 1);
		foreach(array('cancelled','refunded') as $field){
			add_action('woocommerce_order_status_'.$field, array($this, 'adjust_seat_stock_for_order'), 10,1);
		}	

		// cart items validation before checkout
		add_action('evotix_cart_item_validation', array($this, 'cart_validation'), 10, 3);
		
		// saving meta data
		add_action('woocommerce_checkout_create_order_line_item',array($this,'order_item_meta_update_new'),1,4);
		add_action('woocommerce_before_cart_item_quantity_zero',array($this,'update_removed_cart_items'),1,1);

		// set cart session expiration times
		add_filter('wc_session_expiring'   , array($this, 'filter_ExtendSessionExpiring') );
		add_filter('wc_session_expiration' , array($this, 'filter_ExtendSessionExpired') );

		
		// when cart cleared out by session or from purchasing
			add_filter( 'woocommerce_before_cart_item_quantity_zero', array($this,'remove_seat_item_data'), 10, 1 );
			add_filter( 'woocommerce_cart_emptied', array($this,'remove_seat_item_data'), 10, 1 );
			add_filter( 'woocommerce_remove_cart_item', array($this,'remove_seat_item_data'), 10, 2 );
			add_filter( 'woocommerce_cart_item_removed', array($this,'remove_seat_item_data'), 10, 2 );

			add_filter( 'woocommerce_cart_updated', array($this,'load_cart'), 10, 2 );

	}

	// remove cart seat item data
		function remove_seat_item_data($cart_item_key = null){
			$data = (array)WC()->session->get( '_evost_seat_data' );

			// if no item is specified delete all item data
			if ( $cart_item_key == null ) {
				WC()->session->set( '_evost_seat_data', array() );
				return;
			}

			// If item is specified, but no data exists, just return
			if(!isset( $data[$cart_item_key] )) return;

			// make seat available
			global $evost;
			$evost->fn->update_seat_status($data[$cart_item_key][1], $data[$cart_item_key][0], 'av');

			unset( $data[$cart_item_key] );

			WC()->session->set( '_evost_seat_data', $data );
		}
		
		// everytime a cart is loaded
		function load_cart(){
			global $evost;

			$cart = WC()->cart;

			if($cart->cart_contents){
				$data = array();
				$expirations = get_option('_evost_expiration');
				
				foreach($cart->cart_contents as $cart_item_key=>$item){
					if(empty($item['evost_seatid'])) continue;

					$evost->fn->run_seat_expiration_check(
						$cart_item_key,
						$item['evost_eventid'], 
						$item['evost_seatid'],
						$expirations
					);
					

				}
			}
		}
	
	// cart item validation at checkout
		function cart_validation($cart_item_key, $cart_item, $event_id){
			$seat_id = wc_get_order_item_meta($cart_item_key ,'_seat_id'); 
			if($seat_id){
				global $eveost;
				$seat_available = $evost->fn->is_seat_available($seat_id, $event_id);
				$ticket_sale_active = $evost->fn->is_ticket_sale_active_for_event($event_id);

				// if seat not available or ticket sale is not active
				if(!$seat_available && !$ticket_sale_active){
					WC()->cart->remove_cart_item($cart_item_key);
					wc_add_notice( 'Seat removed from cart, no longer available for sale!', 'error' );
				}
			}
		}


	// cart session expiration
		function filter_ExtendSessionExpiring($seconds){
			return !empty($this->opt_tx['evost_session_time'])? $this->opt_tx['evost_session_time'] * 60 : $seconds;
		}
		function filter_ExtendSessionExpired($seconds){
			return  !empty($this->opt_tx['evost_session_time'])? 
				(($this->opt_tx['evost_session_time'] * 60 ) + (60 *1)): $seconds;
		}

	// reduce and restock the seat stock
		function reduce_seat_stock($order){
			$order_id = $order->get_id();
			$this->adjust_seat_stock_for_order($order_id,'reduce');
		}
		function restock_seat_stock($order){
			$order_id = $order->get_id();
			$this->adjust_seat_stock_for_order($order_id,'restock');
		}
		function adjust_seat_stock_for_order($order_id,$type='reduce'){
			
			$order = new WC_Order( $order_id );	
			if(sizeof( $order->get_items() ) <= 0) return false;

			global $evost;

			// each order item in the order
		    	foreach ( $order->get_items() as $item_id=>$item) {

		    		if ( $item['product_id'] > 0 ) {
			    		
			    		$event_id = get_post_meta( $item['product_id'], '_eventid', true);  
			    		if(empty($event_id)) continue; // skip non ticket items

			    		$seat_id = wc_get_order_item_meta($item_id ,'_seat_id'); 

			    		if(!$seat_id) continue;			
			    		
			    		if($type == 'reduce'){
			    			$status = 'uav';
			    			$evost->fn->update_seat_field($event_id, $seat_id, 'order_id', $order_id);
			    		}else{
			    			$status = 'av';
			    			$evost->fn->update_seat_field($event_id, $seat_id, 'order_id', '');
			    		}
			    		
			    		$evost->fn->update_seat_status($event_id, $seat_id, $status);

			    		// Sync product stock
			    		//$evost->fn->sync_total_available_seats($item['product_id'], $event_id);
				    }
		    	}
		}
	
	// pass cart meta values to sessions
	    function get_cart_item_meta_values($session_data, $values, $key){

	    	//WC()->session->set( '_evost_seat_data', array($key=>array('seatid'=>$values['evost_seatid'])) );

	    	//$sesh = WC()->session;
	    	//print_r($sesh);

	        // updates values
	        if (array_key_exists( 'evost_price', $values ) ){
	       		$session_data['evost_price'] = $values['evost_price'];
	       		$session_data['data']->set_price( $values['evost_price'] );
	        }
	        if (array_key_exists( 'evost_seatid', $values ) ){
	       		$session_data['evost_seatid'] = $values['evost_seatid'];
	        }

	        if (array_key_exists( 'evost_eventid', $values ) ){
	       		$session_data['evost_eventid'] = $values['evost_eventid'];
	        }   

	        return $session_data;
	    }

	// display custom data in the cart	   
	    function add_to_cart_item_names($product_name, $values, $cart_item_key ) {
	    	global $evost;
	    	
	    	/*code to add custom data on Cart & checkout Page*/    
	        if(isset($values['evost_seatid'])  ){

	        	// update product name link to event page
	        	if(strpos($product_name, '<')!== false){
	        		$name = explode('>', $product_name);
		        	$name = !empty($name[1])? explode('</', $name[1]):$product_name;
		        	$name = is_array($name)? $name[0]: $name;
		        	
		        	$permalink = get_permalink($values['evost_eventid']);
		            $product_name = "<a class='test' href='". $permalink ."'>" . $name . "</a><br/><span class='item_meta_data'>";
	        	}

	        	$return_string = $product_name . "<br/><span class='item_meta_data'>";

	            $return_string .= "<b>Seat Number:</b> <i>" . $evost->fn->get_seat_number_fromid($values['evost_seatid'], $values['evost_eventid']) . "</i>";
	            $return_string .= "</span>"; 
	            
	            return $return_string;
	        }else{    
	        	return $product_name;    
	        }
	    }

    // add custom data as meta data to order item
	    
		function order_item_meta_update_new($item, $cart_item_key, $values, $order){
			global $evost;
			if(isset($values['evost_seatid']) ){	  
				$item->add_meta_data('Seat-Number', $evost->fn->get_seat_number_fromid($values['evost_seatid'], $values['evost_eventid']),true);
		       	$item->add_meta_data('_seat_id', $values['evost_seatid'] ,true);
	        }	
	
		}

	// remove custom data if item removed from cart
		function update_removed_cart_items($cart_item_key){
	        global $woocommerce;
	        // Get cart
	        $cart = $woocommerce->cart->get_cart();
	        
	        // For each item in cart, if item is upsell of deleted product, delete it
	            foreach( $cart as $key => $values){
		        	if(empty($values['evost_seatid']) ) continue;

			        if ( $values['evost_seatid'] == $cart_item_key ){
			            unset( $woocommerce->cart->cart_contents[ $key ] );
			        }
		        }
	    }

	    // alter the cart quantity so user can not add more than one same ticket
		   	function cart_item_quantity($product_quantity, $cart_item_key, $cart_item ){

		   		if(empty($cart_item['evost_seatid']) ) return $product_quantity;
		   		return sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
		   		
		   	}

    // Order details meta display
		function ordermeta_display($output, $obj){
			$output = str_replace('Seat-Number', 'Seat Number', $output); 
			return $output;
		}

	// STYLES:  
		public function register_styles_scripts(){
			if(is_admin()) return;
			global $evost;			
			wp_register_style( 'evost_styles',$evost->assets_path.'ST_styles.css');
			
			wp_register_script('evost_script',$evost->assets_path.'ST_script.js', array('jquery'), $evost->version, true );
			wp_localize_script( 
				'evost_script', 
				'evost_ajax_script', 
				array( 
					'ajaxurl' => admin_url( 'admin-ajax.php' ) , 
					'postnonce' => wp_create_nonce( 'evost_nonce' )
				)
			);
			
			$this->print_scripts();
			add_action( 'wp_enqueue_scripts', array($this,'print_styles' ));				
		}
		public function print_scripts(){	wp_enqueue_script('evost_script');		}
		function print_styles(){	wp_enqueue_style( 'evost_styles');	}

	// event seating front end for event
		function evotx_seating($content, $event_id, $productid){
			global $evost;

			$epmv = get_post_custom($event_id);

			add_filter('evo_frontend_lightbox', array($this, 'lightbox'),10,1);

			if(!empty($epmv['_enable_seat_chart']) && $epmv['_enable_seat_chart'][0]=='yes' && !empty($epmv['_evost_sections']) && (empty($epmv['evcal_repeat']) || (!empty($epmv['evcal_repeat']) && $epmv['evcal_repeat'][0] =='no') ) 
			){
				//$sections = get_post_meta(1, 'aaa1', true);
				//print_r($sections);
				
				$output = '';
				$output .= '<p><a class="evcal_btn evost_show_seat_selection" data-eventid="'.$event_id.'" data-pid="'.$productid.'">Select Seats</a></p>';
				return $output;
			}else{
				return $content;
			}
		}

		function lightbox($array){
			$array['evost_lightbox']= array(
				'id'=>'evost_lightbox',
				'CLclosebtn'=> 'evost_lightbox',
				'CLin'=> 'evost_lightbox_body',
			);
			return $array;
		}

	// SUPPORT functions
		// RETURN: language
			function lang($variable, $default_text){
				global $evost;
				return $evost->lang($variable, $default_text);
			}
		
}